<?php
	if ( !class_exists('ValueAuth') ) {
		class ValueAuth {
			private $api_url;
			private $api_version;
			private $api_token;
			private $site_code;
			private $customer_key;

			function __construct($user_id)
			{
				global $wpdb;
				$result  = $wpdb->get_results($wpdb->prepare( "SELECT meta_key,meta_value  FROM {$wpdb->usermeta} WHERE user_id = %d AND meta_key LIKE 'vauth_%'",$user_id),OBJECT_K);
				$this->api_version   = 'v1';
				$this->api_url       = 'https://api.valueauth.jp';
				$this->customer_key  = $user_id;

				$code_result = $wpdb->get_results("SELECT meta_key,meta_value  FROM {$wpdb->usermeta} WHERE meta_key in('vauth_api_token','vauth_site_code')",OBJECT_K);
				$this->site_code     = !empty($code_result['vauth_site_code']->meta_value) ? $code_result['vauth_site_code']->meta_value : "";
				$this->api_token     = !empty($code_result['vauth_api_token']->meta_value) ? $code_result['vauth_api_token']->meta_value : "";
			}


			function getSite(){
				// contact_idの取得
				$url = sprintf(
					"%s/%s/%s/sitesetting",
					$this->api_url,
					$this->api_version,
					$this->site_code
				);

				$method = 'GET';
				$result = $this->accessApi($url,$method);
				return $result;

			}

			function getContact(){
				// contact_idの取得
				$url = sprintf(
					"%s/%s/%s/twofactor/contact?customer_key=%s",
					$this->api_url,
					$this->api_version,
					$this->site_code,
					$this->customer_key
				);

				$method = 'GET';
				$result = $this->accessApi($url,$method);
				return $result;

			}

			function createContact($type,$address){
				$url = sprintf(
					"%s/%s/%s/twofactor/contact",
					$this->api_url,
					$this->api_version,
					$this->site_code
				);

				$method = 'POST';
				$send_kbn = $this->getSendKbn($type);

				$data = [];
				$data['customer_key'] = $this->customer_key;
				$data['address']      = $address;
				$data['send_kbn']     = $send_kbn;

				$result = $this->accessApi($url,$method,$data);
				return $result;

			}

			function deleteContact($type,$contact_id){

				$url = sprintf(
					"%s/%s/%s/twofactor/contact/%s",
					$this->api_url,
					$this->api_version,
					$this->site_code,
					$contact_id
				);

				$method = 'DELETE';

				$data = [];
				$data['customer_key'] = $this->customer_key;

				$result = $this->accessApi($url,$method,$data);
				return $result;

			}

			function updateContact($type,$contact_id,$address){

				$url = sprintf(
					"%s/%s/%s/twofactor/contact/%s",
					$this->api_url,
					$this->api_version,
					$this->site_code,
					$contact_id
				);

				$method = 'PUT';
				$send_kbn = $this->getSendKbn($type);

				$data = [];
				$data['customer_key'] = $this->customer_key;
				$data['address']      = $address;
				$data['send_kbn']     = $send_kbn;

				$result = $this->accessApi($url,$method,$data);
				return $result;

			}

			function sendTwofactor(){
				$url = sprintf(
					"%s/%s/%s/twofactor?customer_key=%s",
					$this->api_url,
					$this->api_version,
					$this->site_code,
					$this->customer_key
				);

				$method = "GET";
				$result = $this->accessApi($url,$method);
				return $result;
			}


			function confirmTwofactorApi($code=""){
				$url = sprintf(
					"%s/%s/%s/twofactor?customer_key=%s",
					$this->api_url,
					$this->api_version,
					$this->site_code,
					$this->customer_key
					);

				$method = "POST";

				$data = [];
				$data['customer_key'] = $this->customer_key;
				$data['number']     = $code;

				$result = $this->accessApi($url,$method,$data);
				return $result;
			}

			function accessApi($url,$method,$data=[]){
				$header = [
					'Authorization: Bearer '.$this->api_token,
				];

				$ch = curl_init();
				curl_setopt($ch,CURLOPT_HTTPHEADER, $header);
				curl_setopt($ch,CURLOPT_URL, $url);
				curl_setopt($ch,CURLOPT_FOLLOWLOCATION, true);
				curl_setopt($ch,CURLOPT_RETURNTRANSFER, true);
				curl_setopt($ch,CURLOPT_SSL_VERIFYPEER, false);
				curl_setopt($ch,CURLOPT_SSL_VERIFYHOST, false);
				curl_setopt($ch,CURLOPT_POSTFIELDS, http_build_query($data));
				if(in_array($method,['POST'])){
					curl_setopt($ch,CURLOPT_POST, TRUE);
				}else{
					curl_setopt($ch, CURLOPT_CUSTOMREQUEST, $method); // メソッド指定
				}

				$curl_result = curl_exec($ch);
				$curl_info = curl_getinfo($ch);
				curl_close($ch);

				$result = [];
				$result['http_code'] = $curl_info['http_code'];
				$result['result']    = [];
				if (!empty($curl_result)) {
					$result['result'] = json_decode($curl_result);
				}

				return $result;
			}

			function getSendKbn($type){
				$send_kbn = 0;
				switch($type){
					case "sms" :
						$send_kbn = 1;
						break;
					case "mail" :
						$send_kbn = 2;
						break;
					case "ivr" :
					default:
						break;

				}
				return $send_kbn;

			}

			function setSiteCode($site_code){
				$this->site_code = $site_code;
				return $site_code;
			}

			function setApiToken($api_token){
				$this->api_token = $api_token;
				return $api_token;
			}
		}



	}
?>